Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: runtime/vm/dart.cc

Issue 11416136: Only require SSE2 at minimum hardware requirement. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: addressed comment Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/assembler_x64.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/dart.cc
===================================================================
--- runtime/vm/dart.cc (revision 15244)
+++ runtime/vm/dart.cc (working copy)
@@ -78,9 +78,9 @@
Symbols::InitOnce(vm_isolate_);
CPUFeatures::InitOnce();
#if defined(TARGET_ARCH_IA32) || defined(TARGET_ARCH_X64)
- // Dart VM requires at least SSE3.
- if (!CPUFeatures::sse3_supported()) {
- return "SSE3 is required.";
+ // Dart VM requires at least SSE2.
+ if (!CPUFeatures::sse2_supported()) {
+ return "SSE2 is required.";
}
#endif
PremarkingVisitor premarker(vm_isolate_);
« no previous file with comments | « runtime/vm/assembler_x64.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698